@@ -3,9 +3,15 @@ from nsconfig import NSConfig
 from nscspolicy import NSCSPolicy
 from nscsvserver import NSCSVServer
 from nscsvservercspolicybinding import NSCSVServerCSPolicyBinding
+from nscsvserverresponderpolicybinding import NSCSVServerResponderPolicyBinding
 from nscsvserverrewritepolicybinding import NSCSVServerRewritePolicyBinding
 from nslbvserver import NSLBVServer
 from nslbvserverservicebinding import NSLBVServerServiceBinding
+from nsresponderaction import NSResponderAction
+from nsresponderpolicy import NSResponderPolicy
+from nsresponderpolicylabel import NSResponderPolicyLabel
+from nsresponderpolicylabelbinding import NSResponderPolicyLabelBinding
+from nsresponderpolicycsvserverbinding import NSResponderPolicyCSVServerBinding
 from nsrewritepolicy import NSRewritePolicy
 from nsrewritepolicycsvserverbinding import NSRewritePolicyCSVServerBinding
 from nsservice import NSService
@@ -17,9 +23,15 @@ __all__ = [ 'NSBaseResource',
     'NSCSPolicy',
     'NSCSVServer',
     'NSCSVServerCSPolicyBinding',
+    'NSCSVServerResponderPolicyBinding',
     'NSCSVServerRewritePolicyBinding',
     'NSLBVServer',
     'NSLBVServerServiceBinding',
+    'NSResponderAction',
+    'NSResponderPolicy',
+    'NSResponderPolicyLabel',
+    'NSResponderPolicyLabelBinding',
+    'NSResponderPolicyCSVServerBinding',
     'NSRewritePolicy',
     'NSRewritePolicyCSVServerBinding',
     'NSServer',
